resolve_variables

Function resolve_variables 

pub(crate) fn resolve_variables<'a>(
    sql: &'a str,
    vars: &BTreeMap<String, String>,
) -> ResolvedSql<'a>
Resolve psql-style variables (:foo, :'foo', :"foo") in SQL text.

Always returns ResolvedSql with the SQL text (unresolved variables left as-is), a list of unresolved variable names, and whether the pragma was detected. The caller decides whether unresolved variables are errors or warnings.